<?php
namespace App\Http\Controllers;
//use App\Http\Requests\ProfileUpdateRequest;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\View\View;
use App\Models\Country;
use App\Models\State;
use App\Models\City;
use App\Models\Industries;
use App\Models\Study;

class UsersController extends Controller
{
    /**
     * Display the user's profile form.
     */
    public function edit(Request $request): View
    {
        return view('profile.edit', [
            'user' => $request->user(),
        ]);
    }

    /**
     * Update the user's profile information.
     */
    public function update(ProfileUpdateRequest $request): RedirectResponse
    {
        $request->user()->fill($request->validated());

        if ($request->user()->isDirty('email')) {
            $request->user()->email_verified_at = null;
        }

        $request->user()->save();

        return Redirect::route('profile.edit')->with('status', 'profile-updated');
    }

    /**
     * Delete the user's account.
     */
    public function destroy(Request $request): RedirectResponse
    {
        $request->validateWithBag('userDeletion', [
            'password' => ['required', 'current-password'],
        ]);

        $user = $request->user();

        Auth::logout();

        $user->delete();

        $request->session()->invalidate();
        $request->session()->regenerateToken();

        return Redirect::to('/');
    }
	
	public function registration(){
		$countryList=Country::orderby('country_name','asc')->get()->toArray();
		$industriesList=Industries::orderby('industry_name','asc')->get()->toArray();
		return view('frontend.registration',compact('countryList','industriesList'));
	}
	
public function getStateList(Request $request){
		$country_id=$request->get('country_id');
		$stateList=State::where(['country_id'=>$country_id])->get()->toArray();
		$view=view('frontend.Users.ajax_get_state_list',compact('stateList'))->render();
		return response()->json(['success'=>1,'stateView'=>$view]);
	}
	
	
public function getCityList(Request $request)
  {
	$state_id= $request->get('state_id');
	$cityList=City::Where(['state_id'=>$state_id])->get()->toArray();
    $view=view('frontend.Users.ajax_get_city_list',compact('cityList'))->render();
   	return response()->json(['success'=>1,'cityView'=>$view]);
  } 
	
public function getOtherStateTextbox(Request $request)
 {
	 $view=view('frontend.Users.ajax_get_other_state_text_box')->render();
     return response()->json(['success'=>1,'otherView'=>$view]);
 }	
	
public function getOtherCityTextbox(Request $request){
	$view=view('frontend.Users.ajax_get_other_city_text_box')->render();
    return response()->json(['success'=>1,'otherView'=>$view]);
}	

public function addEduDetail(Request $request){
	$rowId=$request->get('totalRow');
	$year = array_combine(range(date("Y"), 1970), range(date("Y"), 1970));
	asort($year);
	$view=view('frontend.Users.ajax_get_edu_detail',compact('rowId','year'))->render();
    return response()->json(['success'=>1,'eduDetailView'=>$view]);
}	

public function recruiterRegistration(Request $request){
	 $industriesList=Industries::orderby('industry_name','asc')->get()->toArray();
	 $countryList=Country::orderby('country_name','asc')->get()->toArray();
	 return view('frontend.Users.recruiter_registration',compact('industriesList','countryList'));
 }


// Admin logout

public function logout(Request $request): RedirectResponse{
	    Auth::guard('web')->logout();
        $request->session()->invalidate();
        $request->session()->regenerateToken();
        return redirect('/login');
}

public function syncYoga(){
	return view('admin.SyncYoga.sync_yoga');
}
public function contactForm(Request $request){
	$input=$request->except('_token');
	if(!empty($input)){
		return Redirect::route('thank_you')->with('status', 'Thank you for your interest in SYNC YOGA study. We have created your profile. As
next step, please review informed consent for screening and medical record release form');
	}
	return view('admin.SyncYoga.contact_form');
}

public function addStudy(Request $request){
	$input=$request->except('_token');
	 if(!empty($input)){
		 Study::create([
            'study_name' => $request->study_name,
            'description' => $request->description,
            'geographical_radius' => $request->geographical_radius,
            'patient_portal_layout' => $request->patient_portal_layout,
            'language' => $request->language,
            'status' => (isset($request->status))?$request->status:0,
            'created_at' => date('Y-m-d H:i:s'),
            'updated_at' => date('Y-m-d H:i:s'),
        ]);
		 return redirect()->route('listStudy')->with('status', 'Study created successfully');
	 }
	return view('admin.Study.add_study');
}

public function screenConsent(){
	return view('admin.SyncYoga.screen_consent');
}

public function thank_you(){
	return view('admin.SyncYoga.thank_you');
}
public function listStudy(){
	return view('admin.Study.list_study');
}
	
}