<?php
namespace App\Http\Controllers;
//use App\Http\Requests\ProfileUpdateRequest;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\View\View;
use App\Models\Country;
use App\Models\State;
use App\Models\City;
use App\Models\Industries;
use App\Models\Study;
use App\Models\ContactForm;

class UsersController extends Controller
{
    /**
     * Display the user's profile form.
     */
    public function edit(Request $request): View
    {
        return view('profile.edit', [
            'user' => $request->user(),
        ]);
    }

    /**
     * Update the user's profile information.
     */
    public function update(ProfileUpdateRequest $request): RedirectResponse
    {
        $request->user()->fill($request->validated());

        if ($request->user()->isDirty('email')) {
            $request->user()->email_verified_at = null;
        }

        $request->user()->save();

        return Redirect::route('profile.edit')->with('status', 'profile-updated');
    }

    /**
     * Delete the user's account.
     */
    public function destroy(Request $request): RedirectResponse
    {
        $request->validateWithBag('userDeletion', [
            'password' => ['required', 'current-password'],
        ]);

        $user = $request->user();

        Auth::logout();

        $user->delete();

        $request->session()->invalidate();
        $request->session()->regenerateToken();

        return Redirect::to('/');
    }
	


// Admin logout

public function logout(Request $request): RedirectResponse{
	    Auth::guard('web')->logout();
        $request->session()->invalidate();
        $request->session()->regenerateToken();
        return redirect('/login');
}

public function syncYoga(){
	return view('admin.SyncYoga.sync_yoga');
}
public function contactForm(Request $request){
	$input=$request->except('_token');
	if(!empty($input)){
		ContactForm::create([
            'first_name' => $request->first_name,
            'middle_name' => $request->middle_name,
            'last_name' => $request->last_name,
            'gender' => $request->gender,
            'dob' => (isset($request->dob) && !empty($request->dob))?date('Y-m-d',strtotime($request->dob)):null,
            'day_time_phone' => $request->day_time_phone,
            'evening_time_phone' => $request->evening_time_phone,
            'email_address' => $request->email_address,
            'country' => $request->country,
            'state' => $request->state,
            'zip' => $request->zip,
            'created_at' => date('Y-m-d H:i:s'),
            'updated_at' => date('Y-m-d H:i:s'),
        ]);
		 return redirect()->route('thank_you');
	}
	return view('admin.SyncYoga.contact_form');
}

public function addStudy(Request $request){
	$input=$request->except('_token');
	 if(!empty($input)){
		 Study::create([
            'study_name' => $request->study_name,
            'description' => $request->description,
            'geographical_radius' => $request->geographical_radius,
            'patient_portal_layout' => $request->patient_portal_layout,
            'language' => $request->language,
            'status' => (isset($request->status))?$request->status:0,
            'created_at' => date('Y-m-d H:i:s'),
            'updated_at' => date('Y-m-d H:i:s'),
        ]);
		 return redirect()->route('listStudy')->with('status', 'Study created successfully');
	 }
	return view('admin.Study.add_study');
}

public function screenConsent(){
	return view('admin.SyncYoga.screen_consent');
}

public function thank_you(){
	return view('admin.SyncYoga.thank_you');
}
public function listStudy(){
	return view('admin.Study.list_study');
}


public function listContactForm(){
	$contactList = ContactForm::paginate(5);
	return view('admin.SyncYoga.list_contact',compact('contactList'));
}
	
}